Documentation
¶
Overview ¶
templ: version: v0.2.680
Index ¶
- func Badge(badge templ.Component) templwind.OptFunc[Opts]
- func Class(class string) templwind.OptFunc[Opts]
- func HXDelete(href string) templwind.OptFunc[Opts]
- func HXGet(href string) templwind.OptFunc[Opts]
- func HXPatch(href string) templwind.OptFunc[Opts]
- func HXPost(href string) templwind.OptFunc[Opts]
- func HXPushURL(hxPushURL bool) templwind.OptFunc[Opts]
- func HXPut(href string) templwind.OptFunc[Opts]
- func HXSwap(hxSwap Swap) templwind.OptFunc[Opts]
- func HXTarget(hxTarget string) templwind.OptFunc[Opts]
- func HXTrigger(hxTrigger []string) templwind.OptFunc[Opts]
- func ID(id string) templwind.OptFunc[Opts]
- func Icon(icon string) templwind.OptFunc[Opts]
- func New(opts ...templwind.OptFunc[Opts]) templ.Component
- func NewWithOpts(opts *Opts) templ.Component
- func Submenu(linkOpts ...*Opts) templwind.OptFunc[Opts]
- func Target(target string) templwind.OptFunc[Opts]
- func Title(title string) templwind.OptFunc[Opts]
- func XOnTrigger(xOnTrigger string) templwind.OptFunc[Opts]
- type Opts
- type Swap
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewWithOpts ¶
NewWithOpts creates a new component with the given opts
Types ¶
type Opts ¶
type Swap ¶
type Swap string
const ( // the default, puts the content inside the target element InnerHTML Swap = "innerHTML" // replaces the entire target element with the returned content OuterHTML Swap = "outerHTML" // prepends the content before the first child inside the target AfterBegin Swap = "afterbegin" // prepends the content before the target in the target’s parent element BeforeBegin Swap = "beforebegin" // appends the content after the last child inside the target BeforeEnd Swap = "beforeend" // appends the content after the target in the target’s parent element AfterEnd Swap = "afterend" // deletes the target element regardless of the response Delete Swap = "delete" // does not append content from response (Out of Band Swaps and Response Headers will still be processed) None Swap = "none" )
Click to show internal directories.
Click to hide internal directories.